# (akien) bear-engine is built in the bear SRPM (same for bear-factory)
# We build against the same version but drop the conflicting files (libs and translations)
# TODO: Work with upstream to make bear-engine a real library and prevent building it
# in each game based upon the engine (so far two, but there's a third one we might package)
%define bear_version 0.7.0

%define mainrel 3
%define snapshot 20141108
%define snaprel 4

Name:           plee-the-bear
Version:        0.7.0
Release:        %mkrel %{mainrel}.%{snapshot}.%{snaprel}
Summary:        2D platform game starring Plee the Bear
Group:          Games/Arcade
License:        GPLv3+ and CC-BY-SA 3.0
URL:            http://www.stuff-o-matic.com/plee-the-bear/
# https://github.com/j-jorge/plee-the-bear
Source0:        %{name}-%{version}+%{snapshot}.tar.xz
# Should be synced with the bear SRPM
Source1:        bear-%{bear_version}.tar.xz

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  docbook-to-man
BuildRequires:  gettext
BuildRequires:  libclaw-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_mixer)

Requires:       %{name}-data >= %{version}
Requires:       bear-engine = 1:%{bear_version}

%description
Plee the Bear is a platform game in which you play an angry bear whose
son has been kidnapped by god. Here is a guy hard to brave! Jump in
this amazing journey to find and rescue your son. Because you want
to rescue him, don't you? Or to slap him? Maybe both…

%files -f %{name}.lang
%doc plee-the-bear/README.md plee-the-bear/LICENSE
%{_gamesbindir}/%{name}
%{_libdir}/bear/libplee_the_bear.so
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/ptb.png
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------

%package        data
Summary:        Data files for Plee the Bear
License:        CC-BY-SA 3.0
BuildArch:      noarch

%description    data
Data files for Plee the Bear, a 2D platform game.

%files          data
%{_gamesdatadir}/%{name}/
%{_datadir}/bear-factory/%{name}/

#----------------------------------------------------------------------

%prep
%setup -q -a1 -n %{name}-%{version}+%{snapshot}
mv bear-%{bear_version} bear

%build
%cmake -DBEAR_ENGINE_INSTALL_LIBRARY_DIR=%{_lib}/bear \
       -DBEAR_EDITORS_ENABLED=OFF \
       -DPTB_INSTALL_CUSTOM_LIBRARY_DIR=%{_lib}/bear \
       -DPTB_INSTALL_DATA_DIR=share/games/%{name} \
       -DPTB_INSTALL_EXECUTABLE_DIR=games
%make

%install
%make_install -C build

%find_lang %{name}

# Remove the content already provided in the bear-engine package
rm -rf %{buildroot}%{_datadir}/cmake \
       %{buildroot}%{_datadir}/locale/*/LC_MESSAGES/bear-engine.mo \
       %{buildroot}%{_datadir}/pixmaps \
       %{buildroot}%{_libdir}/bear/libbear*.so \
       %{buildroot}%{_mandir}/man6/running-bear.6*


%changelog
* Sun Dec 27 2015 daviddavid <daviddavid> 0.7.0-3.20141108.4.mga6
+ Revision: 916051
- rebuild for new boost 1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 0.7.0-3.20141108.3.mga6
+ Revision: 883886
- rebuild for new boost 1.59.0

* Fri Aug 28 2015 cjw <cjw> 0.7.0-3.20141108.2.mga6
+ Revision: 870387
- rebuild with gcc 5

* Tue Mar 17 2015 akien <akien> 0.7.0-3.20141108.1.mga6
+ Revision: 818722
- Add missing BR on mesagl
- Factorise the bear engine libraries via the external bear-engine package
  o Build the game against the same version of the engine, but do not package
    the runtime libs provided by bear-engine (also used by andy-super-great-park)
  o Install the game-specific library to the common %%_libdir/bear path
  o Drop RPATH since bear-engine uses a proper conf file in /etc/ld.so.conf.d/
  o This new packaging prevents conflicts with andy-super-great-park, though
    preventing the build of the bear libraries in each game will have to be
    worked upon with upstream
- Update game to a recent upstream snapshot

* Sat Nov 08 2014 akien <akien> 0.7.0-2.mga5
+ Revision: 796098
- Drop unneeded SDL1.2 dependencies

* Fri Nov 07 2014 akien <akien> 0.7.0-1.mga5
+ Revision: 796040
- imported package plee-the-bear

